package ru.dbotthepony.mc.otm.item;

import net.minecraft.server.level.ServerPlayer;
import net.minecraft.world.InteractionHand;
import net.minecraft.world.InteractionResultHolder;
import net.minecraft.world.entity.LivingEntity;
import net.minecraft.world.entity.player.Player;
import net.minecraft.world.item.*;
import net.minecraft.world.level.Level;
import net.minecraftforge.common.util.FakePlayer;
import org.apache.logging.log4j.core.jmx.Server;
import ru.dbotthepony.mc.otm.capability.AndroidCapabilityPlayer;
import ru.dbotthepony.mc.otm.capability.IAndroidCapability;
import ru.dbotthepony.mc.otm.capability.MatteryCapability;

import java.util.Optional;

public class ItemPill extends Item {
	public enum PillType {
		BECOME_ANDROID,
		BECOME_HUMANE
	}

	public final PillType pill_type;

	public ItemPill(PillType type) {
		super(new Properties().stacksTo(64).rarity(Rarity.UNCOMMON).tab(CreativeModeTab.TAB_MISC));
		this.pill_type = type;
	}

	@Override
	public int getUseDuration(ItemStack p_41454_) {
		return 32;
	}

	@Override
	public InteractionResultHolder<ItemStack> use(Level level, Player ply, InteractionHand hand) {
		if (ply instanceof FakePlayer)
			return super.use(level, ply, hand);

		Optional<IAndroidCapability> resolver = ply.getCapability(MatteryCapability.ANDROID).resolve();

		if (resolver.isEmpty() || !(resolver.get() instanceof AndroidCapabilityPlayer))
			return super.use(level, ply, hand);

		if (this.pill_type == PillType.BECOME_ANDROID && !resolver.get().isAndroid() || this.pill_type == PillType.BECOME_HUMANE && resolver.get().isAndroid()) {
			ply.startUsingItem(hand);
			return InteractionResultHolder.consume(ply.getItemInHand(hand));
		}

		return super.use(level, ply, hand);
	}

	@Override
	public ItemStack finishUsingItem(ItemStack stack, Level level, LivingEntity ent) {
		if (ent instanceof FakePlayer)
			super.finishUsingItem(stack, level, ent);

		if (ent instanceof Player ply) {
			Optional<IAndroidCapability> resolver = ply.getCapability(MatteryCapability.ANDROID).resolve();

			if (resolver.isEmpty() || !(resolver.get() instanceof AndroidCapabilityPlayer))
				return super.finishUsingItem(stack, level, ply);

			if (this.pill_type == PillType.BECOME_ANDROID && !resolver.get().isAndroid()) {
				stack.shrink(1);

				if (ply instanceof ServerPlayer)
					((AndroidCapabilityPlayer) resolver.get()).becomeAndroid();
			} else if (this.pill_type == PillType.BECOME_HUMANE && resolver.get().isAndroid()) {
				stack.shrink(1);

				if (ply instanceof ServerPlayer)
					((AndroidCapabilityPlayer) resolver.get()).becomeHumane();
			}

			return stack;
		}

		return super.finishUsingItem(stack, level, ent);
	}

	@Override
	public UseAnim getUseAnimation(ItemStack p_41452_) {
		return UseAnim.EAT;
	}
}
